aboutsummaryrefslogtreecommitdiffhomepage
path: root/lib/sisu/v6/xml_odf_odt.rb
diff options
context:
space:
mode:
authorRalph Amissah <ralph@amissah.com>2014-08-08 00:16:16 -0400
committerRalph Amissah <ralph@amissah.com>2014-08-08 00:16:16 -0400
commit64e5c9120ffb7a65b96eded0850f481e116f1d3f (patch)
tree201a7c37c9cc8f18a3f760fba6d4202cd0edad43 /lib/sisu/v6/xml_odf_odt.rb
parentv6: commandline, --act0 to --act9, rc-config with flag:act[0-9] (diff)
v6: use opt.act, code internals (simplify, cleaner; remove opt.cmd & opt.mod)
* v5 dp, indentation changed to retain easy comparison with v6
Diffstat (limited to 'lib/sisu/v6/xml_odf_odt.rb')
-rw-r--r--lib/sisu/v6/xml_odf_odt.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/sisu/v6/xml_odf_odt.rb b/lib/sisu/v6/xml_odf_odt.rb
index ff6de3a7..bb69be5d 100644
--- a/lib/sisu/v6/xml_odf_odt.rb
+++ b/lib/sisu/v6/xml_odf_odt.rb
@@ -117,7 +117,7 @@ module SiSU_XML_ODF_ODT
end
SiSU_XML_ODF_ODT::Source::Scroll.new(@particulars).songsheet
rescue
- SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+ SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
__LINE__.to_s + ':' + __FILE__
end
ensure
@@ -150,7 +150,7 @@ module SiSU_XML_ODF_ODT
unless (@md.opt.act[:verbose_plus][:set]==:on \
|| @md.opt.act[:maintenance][:set]==:on)
if @env.processing_path.odt =~/od[ft]/
- #p "rm -r #{@env.processing_path.odt}" if @md.opt.cmd =~/v/
+ #p "rm -r #{@env.processing_path.odt}" if @md.opt.selections.str =~/v/
FileUtils::rm_r(@env.processing_path.odf_pth)
#system("rm -r #{@env.processing_path.odt}")
end
@@ -636,7 +636,7 @@ module SiSU_XML_ODF_ODT
odf_book_idx
odf_metadata
data.each do |dob|
#p dob.obj if dob.obj =~safe_characters and @md.opt.cmd =~/V/ #KEEP
dob.obj='' if dob.obj =~/#{Mx[:lv_o]}\d+:.*?#{Mx[:lv_c]}.+?#{Mx[:pa_non_object_dummy_heading]}/ #fix Mx[:lv_o]
para_array=[]
dob.obj=dob.obj.gsub(/</,'&lt;').gsub(/>/,'&gt;')
@@ -636,7 +636,7 @@ module SiSU_XML_ODF_ODT
odf_metadata
data.each do |dob|
- #p dob.obj if dob.obj =~safe_characters and @md.opt.cmd =~/V/ #KEEP
+ #p dob.obj if dob.obj =~safe_characters and @md.opt.selections.str =~/V/ #KEEP
dob.obj='' if dob.obj =~/#{Mx[:lv_o]}\d+:.*?#{Mx[:lv_c]}.+?#{Mx[:pa_non_object_dummy_heading]}/ #fix Mx[:lv_o]
para_array=[]